.. _minimal_triangular_mesh_dataset:


Minimal triangular mesh dataset
-------------------------------

**Dataset characteristics:**

    :Number of vertices: 3, at the unit vectors of vector space
			 :math:`\mathbb{R}^3`
    :Number of triangles: 1
